package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.OperationDto;
import com.caimei365.user.model.vo.OperationVo;
import com.caimei365.user.model.vo.PaginationVo;
import com.caimei365.user.service.OperationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/19
 */
@Api(tags="运营人员API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/operation")
public class OperationApi {

    private final OperationService operationService;

    /**
     * 添加运营人员
     *
     * spi旧接口：/operation/add
     *
     * @param operationDto {
     *                         mobile    手机号
     *                         linkName  姓名
     *                         userId    用户Id(userID)
     *                         clubId    机构Id
     *                         shopId    供应商Id
     *                         configFlag 确认标志
     *                     }
     */
    @ApiOperation("保存运营人员")
    @PostMapping("/save")
    public ResponseJson addOperation(OperationDto operationDto) {
        return operationService.addOperation(operationDto);
    }

    /**
     * 更新邀请码
     *
     * spi旧接口：/operation/updateInvitationCode
     *
     * @param operationDto {
     *                         id        运营人员Id
     *                     }
     */
    @ApiOperation("更新运营人员邀请码")
    @PostMapping("/code/update")
    public ResponseJson updateInvitationCode(OperationDto operationDto){
        return operationService.updateInvitationCode(operationDto);
    }

    /**
     * 删除运营人员(解绑)
     *
     * spi旧接口：/operation/delete
     *
     * @param operationDto {
     *                         id        运营人员Id
     *                     }
     */
    @ApiOperation("删除运营人员(解绑)")
    @PostMapping("/delete")
    public ResponseJson deleteOperation(OperationDto operationDto) {
        return operationService.unbindOperation(operationDto);
    }

    /**
     * 获取运营人员列表
     *
     * spi旧接口：/operation/list
     *
     * @param operationDto {
     *                         mobile    手机号
     *                         linkName  姓名
     *                         userId    用户Id(userID)
     *                     }
     */
    @ApiOperation("获取运营人员列表")
    @GetMapping("/list")
    public ResponseJson<PaginationVo<OperationVo>> getOperationList(OperationDto operationDto,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return operationService.getOperationList(operationDto, pageNum, pageSize);
    }

}
