package com.caimei365.user.service;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.*;
import com.caimei365.user.model.vo.ClubTemporaryVo;
import org.springframework.http.HttpHeaders;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/8
 */
public interface RegisterService {

    /**
     * 检查账号可以注册
     *
     * @param mobile 手机号
     * @return sucess
     */
    ResponseJson registerCheck(String mobile);

    /**
     * 普通机构入驻(注册)
     *
     * @param clubRegisterDto ClubRegisterDto{
     *                        source            注册来源: 0网站 1小程序
     *                        userName          用户名
     *                        bindMobile        企业绑定手机号
     *                        password          密码
     *                        unionId           微信unionId
     *                        nickName          微信昵称
     *                        avatarUrl         微信头像(旧：headimgurl)
     *                        passWordConfirm   用户确认密码
     *                        smsCode           短信验证码(旧：activationCode)
     *                        isAgreed          是否同意勾选同意协议，1是，其他否
     *                        }
     * @param headers         HttpHeaders
     * @return void
     */
    ResponseJson clubRegister(ClubRegisterDto clubRegisterDto, HttpHeaders headers);

    /**
     * 普通机构升级会员机构
     *
     * @param upgradeDto ClubUpgradeDto:{
     *                   clubId                 机构ID
     *                   userId                 用户ID
     *                   name                   机构名称
     *                   shortName                  机构简称
     *                   contractEmail          邮箱（contractEmail1）
     *                   contractPhone          固定电话
     *                   linkMan                联系人（linkMan1）
     *                   provinceId             省Id
     *                   cityId                 市Id
     *                   townId                 县区Id
     *                   address                地址
     *                   shopPhoto              门头照(headpic)
     *                   businessLicense        营业执照（businessLicenseImage）
     *                   socialCreditCode       统一社会信用代码（socialCreditCode）
     *                   firstClubType          一级分类：医美=1和生美=2
     *                   secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *                   department             医美分类下的门诊和医院则需要填写科室
     *                   medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *                   mainProduct            主打项目（mainpro）
     *                   fax                    传真
     *                   profile                公司简介
     *                   }
     * @param headers    HttpHeaders
     * @return ClubPo
     */
    ResponseJson clubUpgrade(ClubUpgradeDto upgradeDto, HttpHeaders headers);

    /**
     * 协销拉机构上线
     *
     * @param id      暂存机构数据id
     * @param headers HttpHeaders
     * @return ClubPo
     */
    ResponseJson<Integer> clubOnline(Integer id, HttpHeaders headers);

    /**
     * 小程序端分步供应商注册
     *
     * @param shopRegisterDto ShopRegisterDto{
     *                        source                注册来源: 0网站 1小程序
     *                        name                  组织名称
     *                        shortName                 供应商公司简称(shortName)
     *                        bindMobile            企业绑定手机号
     *                        email                 邮箱
     *                        password              密码
     *                        linkMan               联系人
     *                        provinceId            省(provinceID)
     *                        cityId                市(cityID)
     *                        townId                所在县区Id(townID)
     *                        address               地址
     *                        socialCreditCode      统一社会信用代码
     *                        businessLicense       营业执照(businessLicenseImage)
     *                        firstShopType         医疗=1和非医疗=2
     *                        secondShopType        医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     *                        mainProduct           主打项目(mainpro)
     *                        }
     * @param passWordConfirm 用户确认密码
     * @param smsCode         短信验证码(旧：activationCode)
     * @param isAgreed        是否同意勾选同意协议，1是，其他否
     * @param whichStep       注册步数: PC(0)，小程序(1,2,3)
     * @param headers         HttpHeaders
     * @return ShopPo
     */
    ResponseJson shopRegister(ShopRegisterDto shopRegisterDto, String passWordConfirm, String smsCode, Integer isAgreed, Integer whichStep, HttpHeaders headers);

    /**
     * 更新供应商申请信息
     *
     * @param shopApplyDto ShopRegisterDto
     * @param headers      HttpHeaders
     * @return ShopPo
     */
    ResponseJson updateShopApply(ShopApplyDto shopApplyDto, HttpHeaders headers);

    /**
     * 引导升级后改变guideFlag状态
     *
     * @param userId
     */
    ResponseJson updateGuideFlag(Integer userId);

    /**
     * 暂时存储机构资料
     *
     * @param onlineDto
     * @return
     */
    ResponseJson<Integer> clubTemporary(ClubOnlineDto onlineDto);

    /**
     * 查询暂时存储数据
     *
     * @param id
     * @return
     */
    ResponseJson<ClubTemporaryVo> temporaryData(Integer id);

    /**
     * 购买超级会员
     * @param superVipDto
     * @param headers
     * @return
     */
    ResponseJson superVipUpgrade(SuperVipDto superVipDto, HttpHeaders headers);

    /**
     * 采美豆购买超级会员
     * @param superVipDto
     * @param headers
     * @return
     */
    ResponseJson superVipUpByBeans(SuperVipDto superVipDto, HttpHeaders headers);
}
